==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Exception/Base.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::Base::BEGIN{package Exception::Base;no warnings;require base;do{
"\x62\x61\x73\x65"->import ("\x45\x72\x72\x6f\x72")};}sub Exception::Base::new{
package Exception::Base;no warnings;(my $self=shift (@_));(my $text=(("").shift 
(@_)));(my (@args)=());(local $Error::Depth=($Error::Depth+(0x0a17+ 1020-0x0e12)
));(local $Error::Debug=(0x0a66+ 5757-0x20e2));(my ($pkg,$file,$line,$sub)=
caller ($Error::Depth));$self->SUPER::new ((-"\x74\x65\x78\x74"),$text,(-
"\x63\x73\x75\x62"),$sub,@args);}sub Exception::Base::notify{package 
Exception::Base;no warnings;(my $self=shift (@_));(my $text=$self->text);
main::nxwrite (main::nxgetSTDOUT (),((((
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x20".$text)."\x20").$self->csub).
"\x0a"));(my $trace=$self->stacktrace);main::nxwrite (main::nxgetSTDOUT (),
$trace);}sub Exception::Base::csub{package Exception::Base;no warnings;(my $self
=shift (@_));(exists ($$self{"\x2d\x63\x73\x75\x62"})?$$self{
"\x2d\x63\x73\x75\x62"}:undef);}package Exception::Base;no warnings;
"\x3f\x3f\x3f";

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Exception/Base.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::Base::BEGIN{package Exception::Base;no warnings;require base;do{
"\x62\x61\x73\x65"->import ("\x45\x72\x72\x6f\x72")};}sub Exception::Base::new{
package Exception::Base;no warnings;(my $self=shift (@_));(my $text=(("").shift 
(@_)));(my (@args)=());(local $Error::Depth=($Error::Depth+(0x0114+ 3027-0x0ce6)
));(local $Error::Debug=(0x1293+ 4312-0x236a));(my ($pkg,$file,$line,$sub)=
caller ($Error::Depth));$self->SUPER::new ((-"\x74\x65\x78\x74"),$text,(-
"\x63\x73\x75\x62"),$sub,@args);}sub Exception::Base::notify{package 
Exception::Base;no warnings;(my $self=shift (@_));(my $text=$self->text);
main::nxwrite (main::nxgetSTDOUT (),((((
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x20".$text)."\x20").$self->csub).
"\x0a"));(my $trace=$self->stacktrace);main::nxwrite (main::nxgetSTDOUT (),
$trace);}sub Exception::Base::csub{package Exception::Base;no warnings;(my $self
=shift (@_));(exists ($$self{"\x2d\x63\x73\x75\x62"})?$$self{
"\x2d\x63\x73\x75\x62"}:undef);}package Exception::Base;no warnings;
"\x3f\x3f\x3f";
